%This script builds on scripts provided by McKay (see McKay and
%Reis 2008)

% It computes parts of Table 1, Table 2 and Table 7 of the Appendix in Abbritti Fahr (2013)

% To reproduce Table 1 columns 1-5: outliercorr=0 or =1, kernel_=1 or =3, white_=1 or =0
% To reproduce Table 2: outliercorr=1, kernel_=1, white_=1
% To reproduce Table 7, apply in turn
%    1. MRswitch=1; MRorig=1; MRsample=1948
%    2. MRswitch=1; MRorig=0; MRsample=1948
%    3. MRswitch=1; MRorig=1; MRsample=1952
%    4. MRswitch=1; MRorig=0; MRsample=1952
%    5. MRswitch=1; MRorig=0; MRsample=1970

clear all;
global kernel_;
global white_;


outliercorr = 1; % =1 corrects for outliers
MRswitch = 0;    % =1 follow McKay and Reis definitions of employment (1-ur) 
MRorig = 0;      % =1 reproduces McKay and Reis results with US data
MRsample=1952;   % starting sample date: alternatives are 1948, 1952, 1970;

kernel_=1;      % kernel_   -  indicator for kernel method
                % if kernel_ = 1, then Parzen kernel is used
                % if kernel_ = 2, then Quadratic Spectral kernel is used
                % if kernel_ = 3, then Bartlett (Newey-West) kernel is used

white_ =1;      % white_    -  pre-whiten error indicator
                % if white_ = 1, then the errors are pre-whitened with a VAR(1)
                % before kernel is applied.


global time;
currdir = pwd;
addpath(genpath([pwd '\supportfiles']))
clc;
load data/quarterly_SF2.mat;


if MRswitch ==1; 
    file_add='MR'; 
    if MRswitch ==1; file_add = [file_add 'orig']; end;
    filegdp_add='';    
    fileemp_add='emp rate';
else
    file_add='AF';
    filegdp_add='pc';
    fileemp_add='employment'; 
end;
if outliercorr == 1; file_add=[file_add 'out']; end;

k_s         = [1 2 4 6 8]; %5 quarter lengths

if MRorig == 1; 
    country = ['US']; 
else
    country = ['DE';'FR';'UK';'US';'EA']; 
end;

allvarNames= [];
varNames3  = [];
varnam_add = [];    
varnam_add = strvcat(varnam_add,'raw growth');
varnam_add = strvcat(varnam_add,'log diff');
varnam_add = strvcat(varnam_add,'linear');
varnam_add = strvcat(varnam_add,'polynomial');
varnam_add = strvcat(varnam_add,'bandpass');
varnam_add = strvcat(varnam_add,'rotemberg');

filtnum    = size(varnam_add,1);
lagnum     = size(k_s,2);
countnum   = size(country,1);
if MRorig==1; 
    varnum = 2; 
    totalskewback = zeros(filtnum,225,2,countnum);
    totalskew     = zeros(filtnum,225,2,countnum);
    totalskewroll = zeros(filtnum,225,2,countnum);
else
    varnum = 8; 
    totalskewback = zeros(filtnum,166,8,countnum);
    totalskew     = zeros(filtnum,166,8,countnum);
    %totalskewroll = zeros(filtnum,166,2,countnum);
end;

skewCoeffs  = -99 * ones(filtnum,lagnum,varnum,countnum);
testStats   = -99 * ones(filtnum,lagnum,varnum,countnum);
pVals       = -99 * ones(filtnum,lagnum,varnum,countnum);  %one-sided test



for m= 1: size(country,1) % 5 countries 
	varNames = 'k' ;
    nomcomp = eval(['nomcomp'  country(m,:)]);
    gdpdef  = eval(['gdpdef' country(m,:)]);
    unemp   = eval(['unemp'  country(m,:)]);
    emp     = eval(['emp' country(m,:)]);
    vac     = eval(['vac' country(m,:)]);
    gdp     = eval(['gdp' country(m,:)]);
    invest  = eval(['invest' country(m,:)]);
    pop     = eval(['pop' country(m,:)]);
%    gdpcap  = eval(['gdpcap' country(m,:)]);
    if MRswitch == 1; 
        data = [nomcomp gdpdef nomcomp./gdpdef  unemp (100-unemp) vac invest gdp ];
        varnam = ['nomcomp '; 'gdpdef  '; 'realcomp'; 'unemploy';'emprate ';  'vacancie'; 'investme'; 'realGDP '];
    else
        data = [nomcomp gdpdef nomcomp./gdpdef unemp emp./pop  vac invest./pop gdp./pop ];
        varnam = ['nomcomp '; 'gdpdef  '; 'realcomp'; 'unemploy'; 'employme'; 'vacancie'; 'investme'; 'GDPpc   '];
    end
    signskew = [1; 1; 1; -1; 1; -1; -1; -1];

    if MRorig == 1; 
        clear('unemp','gdp')
        if MRsample==1952;
            load data/quarterly_short1952.mat;
        elseif MRsample==1970;
            load data/quarterly_short1970.mat;
        else
            load data/quarterly_orig.mat;
        end
        file_add = [file_add num2str(MRsample)];        
        gdp     = eval(['gdp']);
        emp     = eval(['emp']);
        data    = [(100-unemp) gdp ];
        varnam  = ['emprate ';'realGDP '];
        signskew= [-1; -1];
    end;
    
    varNames    = [];
    varNames2   = [];
    for i = 1:size(k_s,2) % 5 lag lengths
        k = k_s(i);
        for j = 1:size(varnam_add,1) % 6 types of filters
            switch j
                case 1
                    diff = data(1+k:end,:)./data(1:end-k,:)-1;
                case 2
                	diff = log(data(1+k:end,:)) - log(data(1:end-k,:));
                case 3
                    for variab = 1:varnum
                        y = log(data(:,variab));
                        y = y - linBreak(y,1973.75,1995.75);    
                        diff(:,variab) = y(1+k:end) - y(1:end-k);
                    end
                case 4
                    for variab = 1:varnum
                        y = log(data(:,variab));
                        y = y - polynomial(y,3);
                        diff(:,variab) = y(1+k:end) - y(1:end-k);
                    end
                case 5
                    for variab = 1:varnum
                        y = log(data(:,variab));
                        y = y - bandpass(y,6,32);
                        diff(:,variab) = y(1+k:end) - y(1:end-k);
                    end                    
                case 6
                    for variab = 1:varnum
                        y = log(data(:,variab));
                        y = y - rotemberg(y);
                        diff(:,variab) = y(1+k:end) - y(1:end-k);
                    end                    
            end
            if outliercorr == 1;
                difftmp=diff;
            	difftmp(diff>repmat(nanmedian(difftmp)+3.5*nanstd(diff),length(diff),1))=NaN;
                difftmp(difftmp<repmat(nanmedian(difftmp)-3.5*nanstd(difftmp),length(diff),1))=NaN;
                diff=difftmp;
            end;                    
            
            [s t]             = skewTestAC2(diff);
            skewCoeffs(j,i,:,m) = s;
            testStats(j,i,:,m)  = t;
            pVals(j,i,:,m)      = pnorm(t.*(-signskew'));
            %varNames        = [varnam repmat(country(m,:),8,1) repmat(varnam_add(j,:),8,1) repmat(file_add,8,1)];
            %varNamesstack   = strvcat(varNamesstack ,[varnam repmat(country(m,:),8,1) repmat(varnam_add(j,:),8,1) repmat(file_add,8,1)]);
%             for varpos = 1:8
%                 varNames2   = [repmat(varnam(varpos,:),6,1) repmat(country(m,:),6,1) varnam_add repmat(file_add,6,1)];
%             end
%             varNamesstack2  = strvcat(varNamesstack2,[varnam repmat(country(m,:),8,1) repmat(varnam_add(j,:),8,1) repmat(file_add,8,1)]);            
            
            if k==4, 
                for h=12:length(diff), 
                	for count = 1:varnum
                        totalskew(j,h+k,count,m) = skewness(diff(1:h,count)); 
                        totalskewback(j,end-h+1,count,m) = skewness(diff(end-h+1:end,count)); 
                    end
                end; 
                for h=40:length(diff), 
                    for count = 1:varnum
                        totalskewroll(j,h+k,count,m) = skewness(diff(h-30+1:h,count)); 
                    end
                end;
            end;
        end
    end


varNamesstackcountry = strvcat(' ',varNames2);

% present sorting by country, grouping by filtering technique and circuling
% through variables
    stemp = [reshape(shiftdim(skewCoeffs(:,:,:,m),2),varnum*filtnum,lagnum)];
    ttemp = [reshape(shiftdim(testStats(:,:,:,m),2),varnum*filtnum,lagnum)];
    ptemp = [reshape(shiftdim(pVals(:,:,:,m),2),varnum*filtnum,lagnum)];

    for filternum = 1:filtnum
        varNames3   = strvcat(varNames3,[varnam repmat(' ',varnum,1) repmat(varnam_add(filternum,:),varnum,1)]);
    end

    if exist(['results_by_country_filter' file_add], 'dir')~=7; mkdir(['results_by_country_filter' file_add]); end;
    cd(['results_by_country_filter' file_add])
    
    labelscell = mat2cell(varNames3,ones(size(varNames3,1),1),size(varNames3,2));
    headerscell= [k_s];
    output = stemp;
    matrix2SWP_forskew(output, ['result_by_country_sort_by_filter_' country(m,:) '_skew_' file_add '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    output = ttemp;
    matrix2SWP_forskew(output, ['result_by_country_sort_by_filter_' country(m,:) '_tstat_' file_add '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    output = ptemp;
    matrix2SWP_forskew(output, ['result_by_country_sort_by_filter_' country(m,:) '_pval_' file_add '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    cd('..')
% present sorting by country, grouping by variable and circuling through
% filtering technique
 
    skewCoeffs_ord = [];
    testStats_ord = [];
    pVals_ord = [];
    for varpos =1:varnum
        skewCoeffs_ord = cat(1,skewCoeffs_ord,skewCoeffs(:,:,varpos,m));
        testStats_ord = cat(1,testStats_ord,testStats(:,:,varpos,m));
        pVals_ord = cat(1,pVals_ord,pVals(:,:,varpos,m));
        varNames2   = strvcat(varNames2,[repmat(country(m,:),filtnum,1) repmat(' ',filtnum,1) repmat(varnam(varpos,:),filtnum,1) repmat(' ',filtnum,1) varnam_add repmat(file_add,filtnum,1)]);
    end

    if exist(['results_by_country_variable' file_add], 'dir')~=7; mkdir(['results_by_country_variable' file_add]); end;
    cd(['results_by_country_variable' file_add])
    labelscell = mat2cell(varNames2,ones(size(varNames2,1),1),size(varNames2,2));
    %labelscell = varNames2;
    headerscell= [k_s];    
    output = skewCoeffs_ord;
    matrix2SWP_forskew(output, ['result_by_country_sort_by_variable_' country(m,:) '_skew_' file_add '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    output = testStats_ord;
    matrix2SWP_forskew(output, ['result_by_country_sort_by_variable_' country(m,:) '_tstat_' file_add '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    output = pVals_ord;
    matrix2SWP_forskew(output, ['result_by_country_sort_by_variable_' country(m,:) '_pval_' file_add '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    cd('..')
end



varNames4 = [];

if exist(['AppendTable1Table2Table7' file_add], 'dir')~=7; mkdir(['AppendTable1Table2Table7' file_add]); end;
cd(['AppendTable1Table2Table7' file_add])

for j = 1:filtnum
    skewCoeffs_ord = [];
    testStats_ord = [];
    pVals_ord = [];
    for varpos =1:varnum
        if MRorig ==1 
            skewCoeffs_ord = cat(1,skewCoeffs_ord,squeeze(skewCoeffs(j,:,varpos,:)));
            testStats_ord = cat(1,testStats_ord,squeeze(testStats(j,:,varpos,:)));
            pVals_ord = cat(1,pVals_ord,squeeze(pVals(j,:,varpos,:)));
        else
            skewCoeffs_ord = cat(1,skewCoeffs_ord,squeeze(skewCoeffs(j,:,varpos,:))');
            testStats_ord = cat(1,testStats_ord,squeeze(testStats(j,:,varpos,:))');
            pVals_ord = cat(1,pVals_ord,squeeze(pVals(j,:,varpos,:))');
        end
        varNames4   = strvcat(varNames4,[country repmat(varnam(varpos,:),countnum,1) repmat(varnam_add(j,:),countnum,1) repmat(file_add,countnum,1)]);    
    end
    
    labelscell = mat2cell(varNames4,ones(size(varNames4,1),1),size(varNames4,2));
    output = skewCoeffs_ord;
    matrix2SWP_forskew(output, ['AppendTable1Table2Table7_grouped_by_filtering_sort_by_variable_' varnam_add(j,:) '_skew_.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    output = testStats_ord;
    matrix2SWP_forskew(output, ['AppendTable1Table2Table7_grouped_by_filtering_sort_by_variable_' varnam_add(j,:) '_tstat_.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
    output = pVals_ord;
    matrix2SWP_forskew(output, ['AppendTable1Table2Table7_grouped_by_filtering_sort_by_variable_' varnam_add(j,:) '_pval_.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')
end
cd('..')

    



% allvarnames=cat(varNames,3);
%     
% 
% 
% allvarNames = cat(3,allvarNames,varNames);
% end
% 
% 
% 
% 
% headerscell= [k_s];



% varlabel3=[];
% varlabel = varNames(2:end,:);
%     for j=1:10
%         outputtable(3*(j-1)+1,:) = skewCoeffs(j,:,1);
%         outputtable(3*(j-1)+2,:) = testStats(j,:,1);
%         outputtable(3*(j-1)+3,:) = pVals(j,:,1);        
%         varlabel3 =  strvcat(varlabel3,varlabel(j,:));
%         varlabel3 =  strvcat(varlabel3,'t-stat');
%         varlabel3 =  strvcat(varlabel3,'p-val');
%     end
% labelscell  = mat2cell(varlabel3,ones(size(varlabel3,1),1),size(varlabel3,2));
% headerscell = [k_s];
% matrix2SWP_forskew(outputtable, ['test.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f')

% 
% 
% for m = 1:length(country)
%     subplot(5,2,1+(m-1)*2)
%     plot(...
%         time(1:end),totalskewroll(1,1:end,m)',...
%         time(1:end),totalskewroll(3,1:end,m)',...
%         time(1:end),totalskewroll(4,1:end,m)',...
%         time(1:end),totalskewroll(5,1:end,m)');
%     hold on
%     plot([time(1) time(166)],[0 0],'k')
%     hold off    
%     if m==1; title('GDP per capita'); end;
%     
%     ylabel(country(m,:))    
%     
% 	subplot(5,2,2+(m-1)*2)
%     plot(...
%         time(1:end),totalskewroll(6,1:end,m)',...
%         time(1:end),totalskewroll(8,1:end,m)',...
%         time(1:end),totalskewroll(9,1:end,m)',...
%         time(1:end),totalskewroll(10,1:end,m)');
%     hold on
%     plot([time(1) time(166)],[0 0],'k')
%     hold off    
%     if m==1; title('Employment'); end;
% 
% %     subplot(5,3,3+(m-1)*3)
% %     plot(...
% %         time(1:end),totalskewroll(11,1:end,m)',...
% %         time(1:end),totalskewroll(13,1:end,m)',...
% %         time(1:end),totalskewroll(14,1:end,m)',...
% %         time(1:end),totalskewroll(15,1:end,m)');
% %     hold on
% %     plot([time(1) time(166)],[0 0],'k')
% %     hold off   
% %     if m==1; title('Nominal compensation'); end;       
% end
%     legend(strvcat('raw','polynomial','bandpass','rotemberg'))
% 
% figure
% 
% for m = 1:length(country)
%     subplot(5,2,1+(m-1)*2)
%     plot(...
%         time(12+4+1:166),totalskew(1,12+4+1:166,m)',...
%         time(12+4+1:166),totalskew(3,12+4+1:166,m)',...
%         time(12+4+1:166),totalskew(4,12+4+1:166,m)',...
%         time(12+4+1:166),totalskew(5,12+4+1:166,m)');
%     hold on
%     plot([time(13) time(162)],[0 0],'k')
%     hold off
%     if m==1; title('GDP per capita'); end;
% 
%     ylabel(country(m,:))
%     
%     
% 	subplot(5,2,2+(m-1)*2)
%     plot(...
%         time(12+4+1:166),totalskew(6,12+4+1:166,m)',...
%         time(12+4+1:166),totalskew(8,12+4+1:166,m)',...
%         time(12+4+1:166),totalskew(9,12+4+1:166,m)',...
%         time(12+4+1:166),totalskew(10,12+4+1:166,m)');
%     hold on
%     plot([time(13) time(162)],[0 0],'k')
%     hold off
%     if m==1; title('Employment'); end;
% 
% %     subplot(5,3,3+(m-1)*3)
% %     plot(...
% %         time(12+4+1:166),totalskew(11,12+4+1:166,m)',...
% %         time(12+4+1:166),totalskew(13,12+4+1:166,m)',...
% %         time(12+4+1:166),totalskew(14,12+4+1:166,m)',...
% %         time(12+4+1:166),totalskew(15,12+4+1:166,m)');
% %     hold on
% %     plot([time(13) time(162)],[0 0],'k')
% %     hold off
% %     if m==1; title('Nominal compensation'); end;    
% end
%     legend(strvcat('raw','polynomial','bandpass','rotemberg'))














%         
% 
%         
%         
%         %Employment: emp rate
%         j=7;
%         if MRswitch == 1; x = log(1-unemp/100); else; x = log(emp); end
%         diff = x(1+k:end) - x(1:end-k);
%         [s t] = skewTestAC(diff);
% 
%         if k==4, 
%         	for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;    
%     
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m)  = t;
%         pVals(j,i,m)      = pnorm(t);
% 
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' raw ' fileemp_add]); end
%     
%     %Linear Detrended Output: emp rate
%         j=7;
%         if MRswitch == 1; x = log(1-unemp/100); else; x = log(emp); end
%         x= x - linBreak(x,1973.75,1995.75);
% %         rhs = horzcat(ones(length(x),1), [1:length(x)]');
% %         x = x - rhs*ols(x,rhs);
%         diff = x(1+k:end) - x(1:end-k);
% 
%         if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' linear ' fileemp_add]); end
%     
%         %polynomial Detrended Output: emp rate
%         j=8;
%         if MRswitch == 1; x = log(1-unemp/100); else; x = log(emp); end
%         x = x - polynomial(x,3);
%         diff = x(1+k:end) - x(1:end-k);
% 
%        if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;    
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' polynomial ' fileemp_add]); end
%     
%         %Bandpass Detrended Output: emp rate
%         j=9;
%         if MRswitch == 1; x = log(1-unemp/100); else; x = log(emp); end
%         x = bandpass(x,2,80);
%         diff = x(1+k:end) - x(1:end-k);
% 
%     	if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;    
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' bandpass(2,80)' fileemp_add]); end
% 
%     
%         %Rotemberg Detrended Output: emp rate
%         j=10;
%         if MRswitch == 1; x = log(1-unemp/100); else; x = log(emp); end
%         x = x - rotemberg(x);
%         diff = x(1+k:end) - x(1:end-k);
%     
%     	if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' rotemberg' fileemp_add]); end
% 
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         
%         %Raw Output: nomcomp rate
%         j=11;
%         x = log(nomcomp);
%         diff = x(1+k:end) - x(1:end-k);
%         [s t] = skewTestAC(diff);
% 
%        if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;    
%     
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' raw nomcomp rate ']); end
%     
%     %Linear Detrended Output: nomcomp rate
%         j=12;
%         x = log(nomcomp);
%         x= x - linBreak(x,1973.75,1995.75);
% %         rhs = horzcat(ones(length(x),1), [1:length(x)]');
% %         x = x - rhs*ols(x,rhs);
%         diff = x(1+k:end) - x(1:end-k);
% 
%         if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' linear nomcomp rate ']); end
%     
%         %polynomial Detrended Output: nomcomp rate
%         j=13;
%         x = log(nomcomp);
%         x = x - polynomial(x,3);
%         diff = x(1+k:end) - x(1:end-k);
% 
%        if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;    
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' polynomial nomcomp rate ']); end
%     
%         %Bandpass Detrended Output: nomcomp rate
%         j=14;
%         x = log(nomcomp);
%         x = bandpass(x,2,80);
%         diff = x(1+k:end) - x(1:end-k);
% 
%     	if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;    
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' bandpass(2,80) nomcomp rate ']); end
% 
%     
%         %Rotemberg Detrended Output: nomcomp rate
%         j=15;
%         x = log(nomcomp);
%         x = x - rotemberg(x);
%         diff = x(1+k:end) - x(1:end-k);
%     
%     	if k==4, 
%             for h=12:length(diff), 
%                 totalskew(j,h+k,m) = skewness(diff(1:h)); 
%                 totalskewback(j,end-h+1,m) = skewness(diff(end-h+1:end)); 
%             end; 
%             for h=40:length(diff), 
%                 totalskewroll(j,h+k,m) = skewness(diff(h-30+1:h)); 
%             end;
%         end;
%     
%         [s t] = skewTestAC(diff);
%         skewCoeffs(j,i,m) = s;
%         testStats(j,i,m) = t;
%         pVals(j,i,m) = pnorm(t);
%         if i==1, varNames = strvcat(varNames,[country(m,:) ' rotemberg nomcomp rate ']); end        
%         
%         
%         
%         
%         
%         
%     end
% 
% 