% Growth assumptions
g       = 1.004;    % steady state growth rate

% Households
beta    = 0.992;    % discount rate

% Production
alpha   = 0.7;     % prod.fct curvature
delta   = 0.03;    % depreciation rate
TQss    = 1;       % s.s. Tobin Q

% Investment adjustment costs
ADI     = 0.67;        % quadratic part 
psii    = -0.000000000001;  % Degree of asymmetry

% Labour markets 
sss     = 0.35;   % job-finding rate 
qss     = 0.9;    % job-filling rate

Uss     = 0.1;    % unemployment rate
theta   = 0.5;    % Matching function elasticity
eta     = 0.5;    % Bargaining power of employees
epsilon = 11;     % Elasticity of substitution between varieties

% Wage and price rigidities

nu      = 0;        % indexation of wage changes
zeta    = 0.67;     % Calvo probability of not changing prices 0.63-0.70
psi     = zeta*(epsilon-1)/((1-zeta)*(1-zeta*beta)); % Mapping Calvo probability in Rotemberg adjustment costs

% Wage adjustment costs: quadratic + linex function
chiw    = 37.6;  % quadratic component
psiw    = 24100; % degree of asymmetry

% EMPLOYMENT ADJUST. COSTS quadratic + linex function
chin    = 0.000000000001;  % quadratic component
psin    = -0.000000000001;  % degree of asymmetry

% Monetary policy parameters
omegar  = 0.85;     %  	interest rate persistence
omegapi = 1.5;      % 	reaction on inflation
omegau  = 0.25;     %	weight on output growth
omegadpi = 0;       %	weight on change of inflation
piess   = 1;        %  	gross inflation target
piestar = 1;

% Shocks and persistence 
stdez   = 0.64;    % Standard deviation technology shock
roz     = 0.95;    % Persistence technology shock
stdem   = 0.1;     % Standard deviation monetary policy shock
rorisk     = 0.8;  % Persistence risk premium shock 
stderisk   = 0.1;  % Standard deviation risk premium shock

Dgampiss= 0;
wrcss   = 0;
dwrcss  = 0;
omegass = eta;

% Steady state determination
Nss         = 1 - Uss;                          
Rss         = g*piess/beta;                     
RKss        = 1-beta*(1-delta)/g;               
kss         = ((1-alpha)*(epsilon-1)/epsilon/RKss)^(1/alpha)*Nss;
deltaprime  = g-(1-delta);
Iss         = (1-(1-delta)/g)*kss;              
rhoss       = sss/(1-sss)*Uss/Nss;              %exogenous job separation
Mss         = rhoss*Nss;                        %number of matches
searchss    = 1-(1-rhoss)*Nss;                  %number of job seekers
tightss     = sss/qss;                          %labour market tightness
sigmam      = Mss/(searchss*(tightss^(1-theta))); %parameter matching function
vss         = Mss/qss;                          %vacancies
Yss         = (Nss)^alpha * kss^(1-alpha);      %production
piewss      = g*piess;                          %wage inflation
gampiss     = psi*(piess-1)^2/2;                %inflation adjustment costs

Css         = Yss-Iss;
kapss=0.01*Yss/vss;                             %hiring costs as 1% of GDP
whss       = alpha*((epsilon-1)/epsilon)*Yss/Nss-(1-beta*(1-rhoss))*kapss/qss;

b=(whss-eta*(alpha*((epsilon-1)/epsilon)*Yss/Nss+beta*(1-rhoss)*kapss*sss/qss))/(1-eta);
Wss         = whss;                         


% calibrated parameters
lambdass    = 1/Css;
kap         = kapss*lambdass;                   % vacancy posting costs
rho         = rhoss;                            % exogenous job destruction rate